#[repr(u32)]pub enum RuntimeError {
BatchIteratorFailed = 1,
UnknownOrdinal_(u32),
}Expand description
RuntimeError indicates errors that manifest after the Sample server has
begun periodically sampling data. Clients can ignore these errors, though
they could potentially indicate that no SampleReady request will ever arrive,
or that the batch iterator might behave in unexpected ways, such as hanging.
Variants