LogFlusherServerHandler

Trait LogFlusherServerHandler 

pub trait LogFlusherServerHandler<___T = Channel>
where ___T: Transport,
{ // Required method fn wait_until_flushed( &mut self, responder: Responder<WaitUntilFlushed, ___T>, ) -> impl Future<Output = ()> + Send; // Provided method fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send { ... } }
A server handler for the LogFlusher protocol.

See LogFlusher for more details.

Required Methods

fn wait_until_flushed( &mut self, responder: Responder<WaitUntilFlushed, ___T>, ) -> impl Future<Output = ()> + Send

Flushes all pending logs through the logging pipeline to the serial port. Logs written to sockets prior to the call to Flush are guaranteed to be fully written to serial when this returns. Logs written to sockets after this call has been received by Archivist are not guaranteed to be flushed. Additionally, sockets must actually be connected to the Archivist before this call is made. If a socket hasn’t been received by Archivist yet, those logs may be dropped. To ensure that logs are properly flushed, make sure to wait for the initial interest when logging. Important note: This may be called from the host, but host sockets will NOT be flushed by this method. If you write data from the host (not on the device, there is no guarantee that such logs will ever be printed).

Provided Methods

fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors