pub struct BatchIteratorGetNextResponse {
pub batch: Vec<FormattedContent>,
}Fields
batch: Vec<FormattedContent>Trait Implementations
Sourceimpl CompatFrom<BatchIteratorGetNextResponse> for BatchIteratorGetNextResponse
impl CompatFrom<BatchIteratorGetNextResponse> for BatchIteratorGetNextResponse
Sourcefn compat_from(value: BatchIteratorGetNextResponse) -> Self
fn compat_from(value: BatchIteratorGetNextResponse) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<BatchIteratorGetNextResponse> for BatchIteratorGetNextResponse
impl CompatFrom<BatchIteratorGetNextResponse> for BatchIteratorGetNextResponse
Sourcefn compat_from(value: BatchIteratorGetNextResponse) -> Self
fn compat_from(value: BatchIteratorGetNextResponse) -> Self
Converts
value into a value of this type.Sourceimpl Debug for BatchIteratorGetNextResponse
impl Debug for BatchIteratorGetNextResponse
Sourceimpl<___E> Encode<BatchIteratorGetNextResponse<'static>, ___E> for BatchIteratorGetNextResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<BatchIteratorGetNextResponse<'static>, ___E> for BatchIteratorGetNextResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BatchIteratorGetNextResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BatchIteratorGetNextResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, BatchIteratorGetNextResponse<'static>>, ___E> for BatchIteratorGetNextResponsewhere
___E: Encoder + ?Sized,
BatchIteratorGetNextResponse: Encode<BatchIteratorGetNextResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, BatchIteratorGetNextResponse<'static>>, ___E> for BatchIteratorGetNextResponsewhere
___E: Encoder + ?Sized,
BatchIteratorGetNextResponse: Encode<BatchIteratorGetNextResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BatchIteratorGetNextResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BatchIteratorGetNextResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<BatchIteratorGetNextResponse<'de>> for BatchIteratorGetNextResponse
impl<'de> FromWire<BatchIteratorGetNextResponse<'de>> for BatchIteratorGetNextResponse
Sourcefn from_wire(wire: BatchIteratorGetNextResponse<'de>) -> Self
fn from_wire(wire: BatchIteratorGetNextResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl PartialEq for BatchIteratorGetNextResponse
impl PartialEq for BatchIteratorGetNextResponse
Sourcefn eq(&self, other: &BatchIteratorGetNextResponse) -> bool
fn eq(&self, other: &BatchIteratorGetNextResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BatchIteratorGetNextResponse