#[repr(C)]pub struct BatchIteratorWaitForReadyResponse {}Trait Implementations
Sourceimpl Clone for BatchIteratorWaitForReadyResponse
impl Clone for BatchIteratorWaitForReadyResponse
Sourcefn clone(&self) -> BatchIteratorWaitForReadyResponse
fn clone(&self) -> BatchIteratorWaitForReadyResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<BatchIteratorWaitForReadyResponse, ___E> for &'a BatchIteratorWaitForReadyResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<BatchIteratorWaitForReadyResponse, ___E> for &'a BatchIteratorWaitForReadyResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BatchIteratorWaitForReadyResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BatchIteratorWaitForReadyResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BatchIteratorWaitForReadyResponse, ___E> for BatchIteratorWaitForReadyResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<BatchIteratorWaitForReadyResponse, ___E> for BatchIteratorWaitForReadyResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BatchIteratorWaitForReadyResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BatchIteratorWaitForReadyResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, BatchIteratorWaitForReadyResponse>, ___E> for &'a BatchIteratorWaitForReadyResponsewhere
___E: Encoder + ?Sized,
&'a BatchIteratorWaitForReadyResponse: Encode<BatchIteratorWaitForReadyResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, BatchIteratorWaitForReadyResponse>, ___E> for &'a BatchIteratorWaitForReadyResponsewhere
___E: Encoder + ?Sized,
&'a BatchIteratorWaitForReadyResponse: Encode<BatchIteratorWaitForReadyResponse, ___E>,
Sourcefn encode_option(
this: Option<&'a BatchIteratorWaitForReadyResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BatchIteratorWaitForReadyResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a BatchIteratorWaitForReadyResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BatchIteratorWaitForReadyResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, BatchIteratorWaitForReadyResponse>, ___E> for BatchIteratorWaitForReadyResponsewhere
___E: Encoder + ?Sized,
BatchIteratorWaitForReadyResponse: Encode<BatchIteratorWaitForReadyResponse, ___E>,
impl<___E> EncodeOption<Box<'static, BatchIteratorWaitForReadyResponse>, ___E> for BatchIteratorWaitForReadyResponsewhere
___E: Encoder + ?Sized,
BatchIteratorWaitForReadyResponse: Encode<BatchIteratorWaitForReadyResponse, ___E>,
Sourcefn encode_option(
this: Option<BatchIteratorWaitForReadyResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BatchIteratorWaitForReadyResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<BatchIteratorWaitForReadyResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BatchIteratorWaitForReadyResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<BatchIteratorWaitForReadyResponse> for BatchIteratorWaitForReadyResponse
impl FromWire<BatchIteratorWaitForReadyResponse> for BatchIteratorWaitForReadyResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BatchIteratorWaitForReadyResponse, BatchIteratorWaitForReadyResponse>
const COPY_OPTIMIZATION: CopyOptimization<BatchIteratorWaitForReadyResponse, BatchIteratorWaitForReadyResponse>
Sourcefn from_wire(
wire: BatchIteratorWaitForReadyResponse,
) -> BatchIteratorWaitForReadyResponse
fn from_wire( wire: BatchIteratorWaitForReadyResponse, ) -> BatchIteratorWaitForReadyResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<BatchIteratorWaitForReadyResponse> for BatchIteratorWaitForReadyResponse
impl FromWireRef<BatchIteratorWaitForReadyResponse> for BatchIteratorWaitForReadyResponse
Sourcefn from_wire_ref(
wire: &BatchIteratorWaitForReadyResponse,
) -> BatchIteratorWaitForReadyResponse
fn from_wire_ref( wire: &BatchIteratorWaitForReadyResponse, ) -> BatchIteratorWaitForReadyResponse
Converts the given reference to this type.
Sourceimpl Ord for BatchIteratorWaitForReadyResponse
impl Ord for BatchIteratorWaitForReadyResponse
Sourcefn cmp(&self, other: &BatchIteratorWaitForReadyResponse) -> Ordering
fn cmp(&self, other: &BatchIteratorWaitForReadyResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BatchIteratorWaitForReadyResponse
impl PartialEq for BatchIteratorWaitForReadyResponse
Sourcefn eq(&self, other: &BatchIteratorWaitForReadyResponse) -> bool
fn eq(&self, other: &BatchIteratorWaitForReadyResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BatchIteratorWaitForReadyResponse
impl PartialOrd for BatchIteratorWaitForReadyResponse
impl Copy for BatchIteratorWaitForReadyResponse
impl Eq for BatchIteratorWaitForReadyResponse
impl StructuralPartialEq for BatchIteratorWaitForReadyResponse