pub struct SubtreeSelector {
pub node_path: Vec<StringSelector>,
}Expand description
A selector defining a set of nodes to match, for which the entire subtree including those nodes are selected.
Fields
node_path: Vec<StringSelector>Trait Implementations
Sourceimpl Clone for SubtreeSelector
impl Clone for SubtreeSelector
Sourcefn clone(&self) -> SubtreeSelector
fn clone(&self) -> SubtreeSelector
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<SubtreeSelector> for SubtreeSelector
impl CompatFrom<SubtreeSelector> for SubtreeSelector
Sourcefn compat_from(value: SubtreeSelector) -> SubtreeSelector
fn compat_from(value: SubtreeSelector) -> SubtreeSelector
Converts
value into a value of this type.Sourceimpl Debug for SubtreeSelector
impl Debug for SubtreeSelector
Sourceimpl<'a, ___E> Encode<SubtreeSelector<'static>, ___E> for &'a SubtreeSelectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<SubtreeSelector<'static>, ___E> for &'a SubtreeSelectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SubtreeSelector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SubtreeSelector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SubtreeSelector<'static>, ___E> for SubtreeSelectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<SubtreeSelector<'static>, ___E> for SubtreeSelectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SubtreeSelector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SubtreeSelector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SubtreeSelector<'static>>, ___E> for &'a SubtreeSelector
impl<'a, ___E> EncodeOption<Box<'static, SubtreeSelector<'static>>, ___E> for &'a SubtreeSelector
Sourcefn encode_option(
this: Option<&'a SubtreeSelector>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SubtreeSelector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a SubtreeSelector>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SubtreeSelector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SubtreeSelector<'static>>, ___E> for SubtreeSelector
impl<___E> EncodeOption<Box<'static, SubtreeSelector<'static>>, ___E> for SubtreeSelector
Sourcefn encode_option(
this: Option<SubtreeSelector>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SubtreeSelector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<SubtreeSelector>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SubtreeSelector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<SubtreeSelector<'de>> for SubtreeSelector
impl<'de> FromWire<SubtreeSelector<'de>> for SubtreeSelector
Sourcefn from_wire(wire: SubtreeSelector<'de>) -> SubtreeSelector
fn from_wire(wire: SubtreeSelector<'de>) -> SubtreeSelector
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<SubtreeSelector<'de>> for SubtreeSelector
impl<'de> FromWireRef<SubtreeSelector<'de>> for SubtreeSelector
Sourcefn from_wire_ref(wire: &SubtreeSelector<'de>) -> SubtreeSelector
fn from_wire_ref(wire: &SubtreeSelector<'de>) -> SubtreeSelector
Converts the given reference to this type.
Sourceimpl Hash for SubtreeSelector
impl Hash for SubtreeSelector
Sourceimpl Ord for SubtreeSelector
impl Ord for SubtreeSelector
Sourcefn cmp(&self, other: &SubtreeSelector) -> Ordering
fn cmp(&self, other: &SubtreeSelector) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SubtreeSelector
impl PartialEq for SubtreeSelector
Sourceimpl PartialOrd for SubtreeSelector
impl PartialOrd for SubtreeSelector
impl Eq for SubtreeSelector
impl StructuralPartialEq for SubtreeSelector