#[repr(C)]pub struct LogFlusherWaitUntilFlushedResponse {}Trait Implementations
Sourceimpl Clone for LogFlusherWaitUntilFlushedResponse
impl Clone for LogFlusherWaitUntilFlushedResponse
Sourcefn clone(&self) -> LogFlusherWaitUntilFlushedResponse
fn clone(&self) -> LogFlusherWaitUntilFlushedResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<LogFlusherWaitUntilFlushedResponse, ___E> for &'a LogFlusherWaitUntilFlushedResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<LogFlusherWaitUntilFlushedResponse, ___E> for &'a LogFlusherWaitUntilFlushedResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LogFlusherWaitUntilFlushedResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LogFlusherWaitUntilFlushedResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<LogFlusherWaitUntilFlushedResponse, ___E> for LogFlusherWaitUntilFlushedResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<LogFlusherWaitUntilFlushedResponse, ___E> for LogFlusherWaitUntilFlushedResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LogFlusherWaitUntilFlushedResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LogFlusherWaitUntilFlushedResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, LogFlusherWaitUntilFlushedResponse>, ___E> for &'a LogFlusherWaitUntilFlushedResponsewhere
___E: Encoder + ?Sized,
&'a LogFlusherWaitUntilFlushedResponse: Encode<LogFlusherWaitUntilFlushedResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, LogFlusherWaitUntilFlushedResponse>, ___E> for &'a LogFlusherWaitUntilFlushedResponsewhere
___E: Encoder + ?Sized,
&'a LogFlusherWaitUntilFlushedResponse: Encode<LogFlusherWaitUntilFlushedResponse, ___E>,
Sourcefn encode_option(
this: Option<&'a LogFlusherWaitUntilFlushedResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, LogFlusherWaitUntilFlushedResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a LogFlusherWaitUntilFlushedResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, LogFlusherWaitUntilFlushedResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, LogFlusherWaitUntilFlushedResponse>, ___E> for LogFlusherWaitUntilFlushedResponsewhere
___E: Encoder + ?Sized,
LogFlusherWaitUntilFlushedResponse: Encode<LogFlusherWaitUntilFlushedResponse, ___E>,
impl<___E> EncodeOption<Box<'static, LogFlusherWaitUntilFlushedResponse>, ___E> for LogFlusherWaitUntilFlushedResponsewhere
___E: Encoder + ?Sized,
LogFlusherWaitUntilFlushedResponse: Encode<LogFlusherWaitUntilFlushedResponse, ___E>,
Sourcefn encode_option(
this: Option<LogFlusherWaitUntilFlushedResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, LogFlusherWaitUntilFlushedResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<LogFlusherWaitUntilFlushedResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, LogFlusherWaitUntilFlushedResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<LogFlusherWaitUntilFlushedResponse> for LogFlusherWaitUntilFlushedResponse
impl FromWire<LogFlusherWaitUntilFlushedResponse> for LogFlusherWaitUntilFlushedResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<LogFlusherWaitUntilFlushedResponse, LogFlusherWaitUntilFlushedResponse>
const COPY_OPTIMIZATION: CopyOptimization<LogFlusherWaitUntilFlushedResponse, LogFlusherWaitUntilFlushedResponse>
Sourcefn from_wire(
wire: LogFlusherWaitUntilFlushedResponse,
) -> LogFlusherWaitUntilFlushedResponse
fn from_wire( wire: LogFlusherWaitUntilFlushedResponse, ) -> LogFlusherWaitUntilFlushedResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<LogFlusherWaitUntilFlushedResponse> for LogFlusherWaitUntilFlushedResponse
impl FromWireRef<LogFlusherWaitUntilFlushedResponse> for LogFlusherWaitUntilFlushedResponse
Sourcefn from_wire_ref(
wire: &LogFlusherWaitUntilFlushedResponse,
) -> LogFlusherWaitUntilFlushedResponse
fn from_wire_ref( wire: &LogFlusherWaitUntilFlushedResponse, ) -> LogFlusherWaitUntilFlushedResponse
Converts the given reference to this type.
Sourceimpl Ord for LogFlusherWaitUntilFlushedResponse
impl Ord for LogFlusherWaitUntilFlushedResponse
Sourcefn cmp(&self, other: &LogFlusherWaitUntilFlushedResponse) -> Ordering
fn cmp(&self, other: &LogFlusherWaitUntilFlushedResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LogFlusherWaitUntilFlushedResponse
impl PartialEq for LogFlusherWaitUntilFlushedResponse
Sourcefn eq(&self, other: &LogFlusherWaitUntilFlushedResponse) -> bool
fn eq(&self, other: &LogFlusherWaitUntilFlushedResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for LogFlusherWaitUntilFlushedResponse
impl PartialOrd for LogFlusherWaitUntilFlushedResponse
impl Copy for LogFlusherWaitUntilFlushedResponse
impl Eq for LogFlusherWaitUntilFlushedResponse
impl StructuralPartialEq for LogFlusherWaitUntilFlushedResponse