pub struct PropertySelector {
pub node_path: Vec<StringSelector>,
pub target_properties: StringSelector,
}Expand description
A selector defining a set of nodes to match, and on those matched nodes a set of named properties to match.
Fields
node_path: Vec<StringSelector>target_properties: StringSelectorTrait Implementations
Sourceimpl Clone for PropertySelector
impl Clone for PropertySelector
Sourcefn clone(&self) -> PropertySelector
fn clone(&self) -> PropertySelector
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PropertySelector> for PropertySelector
impl CompatFrom<PropertySelector> for PropertySelector
Sourcefn compat_from(value: PropertySelector) -> PropertySelector
fn compat_from(value: PropertySelector) -> PropertySelector
Converts
value into a value of this type.Sourceimpl Debug for PropertySelector
impl Debug for PropertySelector
Sourceimpl<'a, ___E> Encode<PropertySelector<'static>, ___E> for &'a PropertySelectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<PropertySelector<'static>, ___E> for &'a PropertySelectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PropertySelector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PropertySelector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PropertySelector<'static>, ___E> for PropertySelectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<PropertySelector<'static>, ___E> for PropertySelectorwhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PropertySelector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PropertySelector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PropertySelector<'static>>, ___E> for &'a PropertySelector
impl<'a, ___E> EncodeOption<Box<'static, PropertySelector<'static>>, ___E> for &'a PropertySelector
Sourcefn encode_option(
this: Option<&'a PropertySelector>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PropertySelector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a PropertySelector>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PropertySelector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PropertySelector<'static>>, ___E> for PropertySelector
impl<___E> EncodeOption<Box<'static, PropertySelector<'static>>, ___E> for PropertySelector
Sourcefn encode_option(
this: Option<PropertySelector>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PropertySelector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<PropertySelector>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PropertySelector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PropertySelector<'de>> for PropertySelector
impl<'de> FromWire<PropertySelector<'de>> for PropertySelector
Sourcefn from_wire(wire: PropertySelector<'de>) -> PropertySelector
fn from_wire(wire: PropertySelector<'de>) -> PropertySelector
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PropertySelector<'de>> for PropertySelector
impl<'de> FromWireRef<PropertySelector<'de>> for PropertySelector
Sourcefn from_wire_ref(wire: &PropertySelector<'de>) -> PropertySelector
fn from_wire_ref(wire: &PropertySelector<'de>) -> PropertySelector
Converts the given reference to this type.
Sourceimpl Hash for PropertySelector
impl Hash for PropertySelector
Sourceimpl Ord for PropertySelector
impl Ord for PropertySelector
Sourcefn cmp(&self, other: &PropertySelector) -> Ordering
fn cmp(&self, other: &PropertySelector) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PropertySelector
impl PartialEq for PropertySelector
Sourceimpl PartialOrd for PropertySelector
impl PartialOrd for PropertySelector
impl Eq for PropertySelector
impl StructuralPartialEq for PropertySelector