Sample

Struct Sample 

pub struct Sample;
The type corresponding to the Sample protocol. Configure Archivist to alert you periodically about the state of data provided via SampleParameters.

If the given configuration results in a hit, a BatchIterator is sent over the sink provided. That iterator may be drained, and then the sink will go quiet until the next hit.

Archivist does not inform the client which data result in a success, because it has not inherent advantaged ability to do so. Clients who need to know which data was queried should cache their selectors and use selectors::select_from_hierarchy (or similar in C++).