LogSettingsServerHandler

Trait LogSettingsServerHandler 

pub trait LogSettingsServerHandler<___T = Channel>
where ___T: Transport,
{ // Required method fn set_component_interest( &mut self, request: Request<SetComponentInterest, ___T>, responder: Responder<SetComponentInterest, ___T>, ) -> impl Future<Output = ()> + Send; }
A server handler for the LogSettings protocol.

See LogSettings for more details.

Required Methods

fn set_component_interest( &mut self, request: Request<SetComponentInterest, ___T>, responder: Responder<SetComponentInterest, ___T>, ) -> impl Future<Output = ()> + Send

Requests a change in interest for the matched components.

Each component holds a set of requested interests.

When a new request on LogSettings#SetComponentInterest is received, the sets for matched components receive the new minimum interest. If the interest is less than the previous minimum interest, then a SetComponentInterest request is sent with the new minimum interest.

If a connection to LogSettings sends another SetComponentInterest request, its previous interest request will be undone.

When the connection to LogSettings is finished, the interests are undone, unless persist is set to true. Each matched component minimum interest is updated with the new minimum interest in the set.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors