LogStreamLocalServerHandler

Trait LogStreamLocalServerHandler 

pub trait LogStreamLocalServerHandler<___T: Transport = Channel> {
    // Required method
    fn connect(
        &mut self,
        request: Request<Connect, ___T>,
    ) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A server handler for the LogStream protocol.

See LogStream for more details.

Required Methods

fn connect( &mut self, request: Request<Connect, ___T>, ) -> impl Future<Output = ()>

Enables clients to stream all logs stored in the Archivist. Expects a datagram or stream socket handle that can be written to. If subscribe_to_manifest is used, a stream socket is required, otherwise either a stream or datagram socket can be used.

Logs will be written in the original FXT format with two additional arguments appended at the end of the record depending on the options passed:

- `$__moniker`: the moniker of the component that emitted the log.
- `$__url`: the URL of the component that emitted the log.
- `$__rolled_out`: the number of logs that were rolled out from the
  buffer before this one.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> LogStreamLocalServerHandler<___T> for Local<___H>
where ___H: LogStreamServerHandler<___T>, ___T: Transport,

Source

async fn connect(&mut self, request: Request<Connect, ___T>)

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors