pub trait LogStreamServerHandler<___T: Transport = Channel> {
// Required method
fn connect(
&mut self,
request: Request<Connect, ___T>,
) -> impl Future<Output = ()> + Send;
// Provided method
fn on_unknown_interaction(
&mut self,
ordinal: u64,
) -> impl Future<Output = ()> + Send { ... }
}Expand description
A server handler for the LogStream protocol.
See LogStream for more details.
Required Methods
Sourcefn connect(
&mut self,
request: Request<Connect, ___T>,
) -> impl Future<Output = ()> + Send
fn connect( &mut self, request: Request<Connect, ___T>, ) -> impl Future<Output = ()> + Send
Enables clients to stream all logs stored in the Archivist. Expects a Datagram socket handle that can be written to.
Logs will be written in the original FXT format with two additional arguments appended at the end of the record depending on the options passed:
- `$__moniker`: the moniker of the component that emitted the log.
- `$__url`: the URL of the component that emitted the log.
- `$__rolled_out`: the number of logs that were rolled out from the
buffer before this one.Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.