SampleSinkClientHandler

Trait SampleSinkClientHandler 

pub trait SampleSinkClientHandler<___T: Transport = Channel> {
    // Required method
    fn on_now_or_never(&mut self) -> impl Future<Output = ()> + Send;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> + Send { ... }
}
A client handler for the SampleSink protocol.

See SampleSink for more details.

Required Methods

fn on_now_or_never(&mut self) -> impl Future<Output = ()> + Send

OnNowOrNever initiates a final sample of all data in this server, and exits after the next OnSampleReadied event is drained.

It ignores polling periods but not diffing behavior.

Provided Methods

fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<___T> SampleSinkClientHandler<___T> for IgnoreEvents
where ___T: Transport,

Source

async fn on_now_or_never(&mut self)

Source

async fn on_unknown_interaction(&mut self, _: u64)

Implementors