pub enum TreeNames {
Some(Vec<String>),
All(All),
UnknownOrdinal_(u64),
}Expand description
TreeNames are the set of names of fuchsia.inspect.Trees for a component that were parsed out of a selector. The hierarchy and property selector portions will only be applied to trees that match this set.
Variants
Implementations