pub struct BatchIterator;Expand description
The type corresponding to the BatchIterator protocol. Conceptually, a directory iterator, where each element in the iterator is a single complete file that can be concatenated with other results.