pub trait ArchiveAccessorServerHandler<___T: Transport = Channel> {
// Required methods
fn stream_diagnostics(
&mut self,
request: Request<StreamDiagnostics, ___T>,
) -> impl Future<Output = ()> + Send;
fn wait_for_ready(
&mut self,
responder: Responder<WaitForReady, ___T>,
) -> impl Future<Output = ()> + Send;
// Provided method
fn on_unknown_interaction(
&mut self,
ordinal: u64,
) -> impl Future<Output = ()> + Send { ... }
}Expand description
A server handler for the ArchiveAccessor protocol.
See ArchiveAccessor for more details.
Required Methods
Sourcefn stream_diagnostics(
&mut self,
request: Request<StreamDiagnostics, ___T>,
) -> impl Future<Output = ()> + Send
fn stream_diagnostics( &mut self, request: Request<StreamDiagnostics, ___T>, ) -> impl Future<Output = ()> + Send
Creates an iterator over diagnostics data on the system.
- The iterator may be finite by streaming in SNAPSHOT mode, serving only the current state of diagnostics data on the system.
- The iterator may be infinite by streaming in either SNAPSHOT_THEN_SUBSCRIBE or SUBSCRIBE mode; the prior first provides iteration over the current state of the sytem, and then both provide ongoing iteration over newly arriving diagnostics data.
-
request
result streama [fuchsia.diagnostics/BatchIterator] that diagnostic records are exposed to the client over.- epitaphs:
- INVALID_ARGS: A required argument in the StreamParameters struct was missing.
- WRONG_TYPE: A selector provided by the StreamParameters struct was incorrectly formatted.
- epitaphs:
-
request
stream_parametersis a [fuchsia.diagnostics/StreamParameter] which specifies how to configure the stream.
Sourcefn wait_for_ready(
&mut self,
responder: Responder<WaitForReady, ___T>,
) -> impl Future<Output = ()> + Send
fn wait_for_ready( &mut self, responder: Responder<WaitForReady, ___T>, ) -> impl Future<Output = ()> + Send
Ensures that the connection with the server was established to prevent races when using other pipelined methods of this protocol.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.