SampleSinkLocalClientHandler

Trait SampleSinkLocalClientHandler 

pub trait SampleSinkLocalClientHandler<___T: Transport = Channel> {
    // Required method
    fn on_now_or_never(&mut self) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A client handler for the SampleSink protocol.

See SampleSink for more details.

Required Methods

fn on_now_or_never(&mut self) -> impl Future<Output = ()>

OnNowOrNever initiates a final sample of all data in this server, and exits after the next OnSampleReadied event is drained.

It ignores polling periods but not diffing behavior.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<___H, ___T> SampleSinkLocalClientHandler<___T> for Local<___H>
where ___H: SampleSinkClientHandler<___T>, ___T: Transport,

Source

async fn on_now_or_never(&mut self)

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors